##################################################### 
#          Solutions to Worksheet from Chap. 14     #
#####################################################

# B- Study of multiple linear regression

#  Study of intima-media

# We notice (tobacco[is.na(packyear)] and packyear[tobacco==0]) that
# the variable packyear (giving the number of pack of cigarettes per year) contains missing values NA each time the variable tobacco takes the value 0 (meaning a non smoker). It is thus natural to replace missing data of variable packyear with zeroes:
intima.media$packyear[is.na(packyear)] <- 0
# Creation of the variable BMI:
BMI <- intima.media$weight/((intima.media$height/100)^2)
attach(intima.media)
my.data <- data.frame(AGE,SPORT,alcohol,packyear,BMI,measure)
# 14.1-
pairs(my.data)
#       Some scatter plots have a linear trend, which can lead to collinearity.
# 14.2-
model.age <- lm(measure~AGE,data=my.data)
summary(model.age)
model.sport <- lm(measure~SPORT,data=my.data)
summary(model.sport) ### p-value > 0.25
model.alcohol <- lm(measure~factor(alcohol),data=my.data)
summary(model.alcohol)
model.packyear <- lm(measure~packyear,data=my.data)
summary(model.packyear)
model.BMI <- lm(measure~BMI,data=my.data)
summary(model.BMI)
# 14.3-
model.age.inter <- lm(measure~AGE*packyear)
       # Non-significant interaction at 0.25 level:
summary(model.age.inter)
model.alcohol.without.inter <-
  lm(measure~factor(alcohol)+packyear,data=my.data)
model.alcohol.inter <-
  lm(measure~factor(alcohol)*packyear,data=my.data)
summary(model.alcohol.inter)
anova(model.alcohol.without.inter,model.alcohol.inter)
model.BMI.inter <- lm(measure~BMI*packyear,data=my.data)
      # Non-significant interaction at level 0.25:
summary(model.BMI.inter)
# 14.4-
model.inter <-
  lm(measure~AGE+factor(alcohol)*packyear+BMI,
     data=my.data)
summary(model.inter)
# 14.5-
model.without.inter <- lm(measure~AGE+factor(alcohol)+
                          packyear+BMI,data=my.data)
      # The interaction term is not significant anymore:
anova(model.inter,model.without.inter)
summary(model.without.inter)
# 14.6-
model.without.alcohol <- lm(measure~AGE+packyear+BMI,
                             data=my.data)
anova(model.without.alcohol,model.without.inter)
# The variable alcohol does not bring any information.
summary(model.without.alcohol)
# 14.7- In the final model, the measurement of intima-media is explained by the variables AGE and BMI, with an adjustment on the variable packyear. Whatever the number of packs of cigarettes smoked each year, the measurement of intima-media increases with age and BMI.

# Study of unemployment rates
# 14.1- Download the file  "http://biostatisticien.eu/springeR/unemployment.RData" in your working folder.
load("unemployment.RData")
names(unemployment)
attach(unemployment)
model.txpib <- lm(unemp~gdprate,data=unempolyment)
summary(model.gdprate)
plot(unemp~gdprate)
abline(model.gdprate)
hist(residuals(model.gdprate))
plot(model.gdprate,1:2)
# 14.2-
cor(unemp[,2:7])
# 14.3-
pairs(unemp[,2:7])
# 14.4- Most explicative variables: taxb, govspend, gdprate. Colinear variables: govspend and taxb, as well as govspend and gdprate, and finally taxb and gdprate.
# 14.5-
full.model <- lm(unemp~gdprate+govspend+taxb+salav+infl,
                 data=unemployment)
summary(full.model)
# 14.6-
require("car")
vif(full.model)
# 14.7-
drop1(lm(unemp~gdprate+govspend+taxb+salav+infl,
         data=unemploment),test="F")
       # We remove variable infl.
drop1(lm(unemp~gdprate+govspend+taxb+salaav,
         data=unemployment),test="F")
       # We remove variable txpib.
drop1(lm(unemp~govspend+taxb+salav,data=unemployment),
      test="F")
       # We remove variable pfisc.
drop1(lm(unemp~govspend+salav,data=unemployment),test="F")
# 14.8- # Final model:
final.model <- lm(unemp~govspend+salav,data=unemployment)
summary(final.model)
# 14.9-
govspend93 <- unemployment$govspend[unemployment$year==
                                    1993]
salav93 <- unemployment$salav[unemployment$year==1993]
predict(final.model,data.frame(govspend=govspend93,
                               salav=salav93),
        interval="prediction")
# 14.10- The observed value of unemployment in 1993 was 11:2 and this value is contained in the prediction interval.
